[][src]Trait flv_future_aio::fs::AsyncFile

pub trait AsyncFile {
#[must_use]    fn reset_to_beginning<'life0, 'async_trait>(
        &'life0 mut self
    ) -> Pin<Box<dyn Future<Output = Result<(), IoError>> + Send + 'async_trait>>

Notable traits for Pin<P>

impl<P> Future for Pin<P> where
    P: Unpin + DerefMut,
    <P as Deref>::Target: Future
type Output = <<P as Deref>::Target as Future>::Output;

    where
        'life0: 'async_trait,
        Self: 'async_trait
;
fn raw_slice(&self, position: u64, len: u64) -> AsyncFileSlice;
#[must_use] fn as_slice<'life0, 'async_trait>(
        &'life0 self,
        position: u64,
        desired_len_opt: Option<u64>
    ) -> Pin<Box<dyn Future<Output = Result<AsyncFileSlice, IoError>> + Send + 'async_trait>>

Notable traits for Pin<P>

impl<P> Future for Pin<P> where
    P: Unpin + DerefMut,
    <P as Deref>::Target: Future
type Output = <<P as Deref>::Target as Future>::Output;

    where
        'life0: 'async_trait,
        Self: 'async_trait
; }

Required methods

#[must_use]fn reset_to_beginning<'life0, 'async_trait>(
    &'life0 mut self
) -> Pin<Box<dyn Future<Output = Result<(), IoError>> + Send + 'async_trait>>

Notable traits for Pin<P>

impl<P> Future for Pin<P> where
    P: Unpin + DerefMut,
    <P as Deref>::Target: Future
type Output = <<P as Deref>::Target as Future>::Output;
where
    'life0: 'async_trait,
    Self: 'async_trait, 

fn raw_slice(&self, position: u64, len: u64) -> AsyncFileSlice

#[must_use]fn as_slice<'life0, 'async_trait>(
    &'life0 self,
    position: u64,
    desired_len_opt: Option<u64>
) -> Pin<Box<dyn Future<Output = Result<AsyncFileSlice, IoError>> + Send + 'async_trait>>

Notable traits for Pin<P>

impl<P> Future for Pin<P> where
    P: Unpin + DerefMut,
    <P as Deref>::Target: Future
type Output = <<P as Deref>::Target as Future>::Output;
where
    'life0: 'async_trait,
    Self: 'async_trait, 

Loading content...

Implementors

impl AsyncFile for File[src]

fn raw_slice(&self, position: u64, len: u64) -> AsyncFileSlice[src]

return raw slice with fiel descriptor, this doesn't not check

fn as_slice<'life0, 'async_trait>(
    &'life0 self,
    position: u64,
    desired_len_opt: Option<u64>
) -> Pin<Box<dyn Future<Output = Result<AsyncFileSlice, IoError>> + Send + 'async_trait>>

Notable traits for Pin<P>

impl<P> Future for Pin<P> where
    P: Unpin + DerefMut,
    <P as Deref>::Target: Future
type Output = <<P as Deref>::Target as Future>::Output;
where
    'life0: 'async_trait,
    Self: 'async_trait, 
[src]

Extract slice of file using file descriptor if desired len is not supplied, compute the len from metadata

Loading content...