[][src]Module flv_future_aio::path

Structs

Ancestors

An iterator over Path and its ancestors.

Components

An iterator over the Components of a Path.

Display

Helper struct for safely printing paths with format! and {}.

Iter

An iterator over the Components of a Path, as OsStr slices.

Path

A slice of a path.

PathBuf

This struct is an async version of std::path::PathBuf.

PrefixComponent

A structure wrapping a Windows path prefix as well as its unparsed string representation.

StripPrefixError

An error returned from Path::strip_prefix if the prefix was not found.

Enums

Component

A single component of a path.

Prefix

Windows path prefixes, e.g., C: or \\server\share.

Constants

MAIN_SEPARATOR

The primary separator of path components for the current platform.

Functions

is_separator

Determines whether the character is one of the permitted path separators for the current platform.