[−][src]Struct flv_future_aio::sync::mpsc::Receiver
The receiving side of a channel.
This type receives messages by calling recv. But it also implements the Stream trait,
which means it can act as an asynchronous iterator. This struct is created by the channel
function. See its documentation for more.
Examples
use std::time::Duration; use async_std::sync::channel; use async_std::task; let (s, r) = channel(100); task::spawn(async move { s.send(1usize).await; task::sleep(Duration::from_secs(1)).await; s.send(2).await; }); assert_eq!(r.recv().await?, 1); // Received immediately. assert_eq!(r.recv().await?, 2); // Received after 1 second.
Implementations
impl<T> Receiver<T>[src]
pub async fn recv(&'_ self) -> Result<T, RecvError>[src]
Receives a message from the channel.
If the channel is empty and still has senders, this method will wait until a message is sent into it. Once all senders have been dropped it will return RecvError.
Examples
use async_std::sync::channel; use async_std::task; let (s, r) = channel(1); task::spawn(async move { s.send(1usize).await; s.send(2).await; // Then we drop the sender }); assert_eq!(r.recv().await?, 1); assert_eq!(r.recv().await?, 2); assert!(r.recv().await.is_err());
pub fn try_recv(&self) -> Result<T, TryRecvError>[src]
Attempts to receive a message from the channel.
If the channel is empty, this method will return an error.
Examples
use async_std::sync::channel; let (s, r) = channel(1); s.send(1u8).await; assert!(r.try_recv().is_ok()); assert!(r.try_recv().is_err());
pub fn capacity(&self) -> usize[src]
Returns the channel capacity.
Examples
use async_std::sync::channel; let (_, r) = channel::<i32>(5); assert_eq!(r.capacity(), 5);
pub fn is_empty(&self) -> bool[src]
Returns true if the channel is empty.
Examples
use async_std::sync::channel; let (s, r) = channel(1); assert!(r.is_empty()); s.send(0).await; assert!(!r.is_empty());
pub fn is_full(&self) -> bool[src]
Returns true if the channel is full.
Examples
use async_std::sync::channel; let (s, r) = channel(1); assert!(!r.is_full()); s.send(0).await; assert!(r.is_full());
pub fn len(&self) -> usize[src]
Returns the number of messages in the channel.
Examples
use async_std::sync::channel; let (s, r) = channel(2); assert_eq!(r.len(), 0); s.send(1).await; s.send(2).await; assert_eq!(r.len(), 2);