[−][src]Struct flv_future_aio::sync::BarrierWaitResult
A BarrierWaitResult is returned by wait when all threads in the Barrier have rendezvoused.
Examples
use async_std::sync::Barrier; let barrier = Barrier::new(1); let barrier_wait_result = barrier.wait();
Implementations
impl BarrierWaitResult[src]
pub fn is_leader(&self) -> bool[src]
Returns true if this task from wait is the "leader task".
Only one task will have true returned from their result, all other
tasks will have false returned.
Examples
use async_std::sync::Barrier; let barrier = Barrier::new(1); let barrier_wait_result = barrier.wait().await; println!("{:?}", barrier_wait_result.is_leader());