[−][src]Trait flv_future_aio::fs::AsyncFile
Required methods
#[must_use]fn reset_to_beginning<'life0, 'async_trait>(
&'life0 mut self
) -> Pin<Box<dyn Future<Output = Result<(), IoError>> + Send + 'async_trait>>ⓘ where
'life0: 'async_trait,
Self: 'async_trait,
&'life0 mut self
) -> Pin<Box<dyn Future<Output = Result<(), IoError>> + Send + 'async_trait>>ⓘ where
'life0: 'async_trait,
Self: 'async_trait,
fn raw_slice(&self, position: u64, len: u64) -> AsyncFileSlice
#[must_use]fn as_slice<'life0, 'async_trait>(
&'life0 self,
position: u64,
desired_len_opt: Option<u64>
) -> Pin<Box<dyn Future<Output = Result<AsyncFileSlice, IoError>> + Send + 'async_trait>>ⓘ where
'life0: 'async_trait,
Self: 'async_trait,
&'life0 self,
position: u64,
desired_len_opt: Option<u64>
) -> Pin<Box<dyn Future<Output = Result<AsyncFileSlice, IoError>> + Send + 'async_trait>>ⓘ where
'life0: 'async_trait,
Self: 'async_trait,
Implementors
impl AsyncFile for File[src]
fn reset_to_beginning<'life0, 'async_trait>(
&'life0 mut self
) -> Pin<Box<dyn Future<Output = Result<(), IoError>> + Send + 'async_trait>>ⓘ where
'life0: 'async_trait,
Self: 'async_trait, [src]
&'life0 mut self
) -> Pin<Box<dyn Future<Output = Result<(), IoError>> + Send + 'async_trait>>ⓘ where
'life0: 'async_trait,
Self: 'async_trait,
fn raw_slice(&self, position: u64, len: u64) -> AsyncFileSlice[src]
return raw slice with fiel descriptor, this doesn't not check
fn as_slice<'life0, 'async_trait>(
&'life0 self,
position: u64,
desired_len_opt: Option<u64>
) -> Pin<Box<dyn Future<Output = Result<AsyncFileSlice, IoError>> + Send + 'async_trait>>ⓘ where
'life0: 'async_trait,
Self: 'async_trait, [src]
&'life0 self,
position: u64,
desired_len_opt: Option<u64>
) -> Pin<Box<dyn Future<Output = Result<AsyncFileSlice, IoError>> + Send + 'async_trait>>ⓘ where
'life0: 'async_trait,
Self: 'async_trait,
Extract slice of file using file descriptor if desired len is not supplied, compute the len from metadata