[−][src]Module flv_future_aio::path
Structs
| Ancestors | An iterator over |
| Components | |
| Display | Helper struct for safely printing paths with |
| Iter | |
| Path | A slice of a path. |
| PathBuf | This struct is an async version of |
| PrefixComponent | A structure wrapping a Windows path prefix as well as its unparsed string representation. |
| StripPrefixError | An error returned from |
Enums
| Component | A single component of a path. |
| Prefix | Windows path prefixes, e.g., |
Constants
| MAIN_SEPARATOR | The primary separator of path components for the current platform. |
Functions
| is_separator | Determines whether the character is one of the permitted path separators for the current platform. |